@@ -247,7 +247,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
 
                 preservation_statuses, doi = preservation_status(result)
 
-                md5_doi = hashlib.md5(doi["DOI"].lower().encode())
+                md5_doi = hashlib.md5(doi["DOI"].lower().encode()).hexdigest()
                 aws_key = (
                     f"{ANNOTATION_PATH}/works/{md5_doi}/{ANNOTATION_FILENAME}"
                 )
